cmoncrawl.processor.pipeline.extractor.DomainRecordExtractor.preprocess
=======================================================================

.. currentmodule:: cmoncrawl.processor.pipeline.extractor

.. automethod:: DomainRecordExtractor.preprocess